@@ -20,12 +20,14 @@ package MongoDB::BSON;
 # ABSTRACT: Tools for serializing and deserializing data in BSON form
 
 use version;
-our $VERSION = 'v0.999.998.6'; # TRIAL
+our $VERSION = 'v0.999.999.1'; # TRIAL
 
 use XSLoader;
 XSLoader::load("MongoDB", $VERSION);
 
 use Carp ();
+use Config;
+use if ! $Config{use64bitint}, "Math::BigInt";
 use MongoDB::Error;
 use Moose;
 use MongoDB::_Types -types;
@@ -59,8 +61,9 @@ has dbref_callback => (
 #pod =attr dt_type
 #pod
 #pod Sets the type of object which is returned for BSON DateTime fields. The default
-#pod is L<DateTime>. Other acceptable values are L<DateTime::Tiny> and C<undef>. The
-#pod latter will give you the raw epoch value rather than an object.
+#pod is L<DateTime>. Other acceptable values are L<Time::Moment>, L<DateTime::Tiny>
+#pod and C<undef>. The latter will give you the raw epoch value rather than an
+#pod object.
 #pod
 #pod # XXX add MongoDB::BSON::DateTime support and make it the default
 #pod
@@ -320,7 +323,7 @@ sub decode_one {
 
 #pod =method clone
 #pod
-#pod     $codec->clone( dt_type => 'DateTime::Tiny' );
+#pod     $codec->clone( dt_type => 'Time::Moment' );
 #pod
 #pod Constructs a copy of the original codec, but allows changing
 #pod attributes in the copy.
@@ -354,7 +357,7 @@ MongoDB::BSON - Tools for serializing and deserializing data in BSON form
 
 =head1 VERSION
 
-version v0.999.998.6
+version v0.999.999.1
 
 =head1 SYNOPSIS
 
@@ -388,8 +391,9 @@ The default returns the DBRef hash reference without modification.
 =head2 dt_type
 
 Sets the type of object which is returned for BSON DateTime fields. The default
-is L<DateTime>. Other acceptable values are L<DateTime::Tiny> and C<undef>. The
-latter will give you the raw epoch value rather than an object.
+is L<DateTime>. Other acceptable values are L<Time::Moment>, L<DateTime::Tiny>
+and C<undef>. The latter will give you the raw epoch value rather than an
+object.
 
 # XXX add MongoDB::BSON::DateTime support and make it the default
 
@@ -524,7 +528,7 @@ max_length – overrides codec default
 
 =head2 clone
 
-    $codec->clone( dt_type => 'DateTime::Tiny' );
+    $codec->clone( dt_type => 'Time::Moment' );
 
 Constructs a copy of the original codec, but allows changing
 attributes in the copy.
@@ -539,11 +543,11 @@ David Golden <david@mongodb.com>
 
 =item *
 
-Mike Friedman <friedo@mongodb.com>
+Mike Friedman <friedo@friedo.com>
 
 =item *
 
-Kristina Chodorow <kristina@mongodb.com>
+Kristina Chodorow <k.chodorow@gmail.com>
 
 =item *
 
