@@ -18,7 +18,7 @@ package MongoDB::BSON::Binary;
 # ABSTRACT: MongoDB binary type
 
 use version;
-our $VERSION = 'v0.999.998.6'; # TRIAL
+our $VERSION = 'v0.999.999.1'; # TRIAL
 
 use Moose;
 use Types::Standard -types;
@@ -80,7 +80,7 @@ MongoDB::BSON::Binary - MongoDB binary type
 
 =head1 VERSION
 
-version v0.999.998.6
+version v0.999.999.1
 
 =head1 SYNOPSIS
 
@@ -177,11 +177,11 @@ David Golden <david@mongodb.com>
 
 =item *
 
-Mike Friedman <friedo@mongodb.com>
+Mike Friedman <friedo@friedo.com>
 
 =item *
 
-Kristina Chodorow <kristina@mongodb.com>
+Kristina Chodorow <k.chodorow@gmail.com>
 
 =item *
 
