@@ -19,7 +19,7 @@ package MongoDB::BulkWrite;
 # ABSTRACT: MongoDB bulk write interface
 
 use version;
-our $VERSION = 'v0.999.998.6'; # TRIAL
+our $VERSION = 'v0.999.999.1'; # TRIAL
 
 use MongoDB::Error;
 use MongoDB::OID;
@@ -137,9 +137,9 @@ sub find {
     );
 }
 
-#pod =method insert
+#pod =method insert_one
 #pod
-#pod     $bulk->insert( $doc );
+#pod     $bulk->insert_one( $doc );
 #pod
 #pod Queues a document for insertion when L</execute> is called.  The document may
 #pod be a hash reference, an array reference (with balance key/value pairs) or a
@@ -150,16 +150,16 @@ sub find {
 #pod
 #pod =cut
 
-sub insert {
+sub insert_one {
     my ( $self, $doc ) = @_;
 
     unless ( @_ == 2 && ref $doc eq any(qw/HASH ARRAY Tie::IxHash/) ) {
-        MongoDB::UsageError->throw("argument to insert must be a single hashref, arrayref or Tie::IxHash");
+        MongoDB::UsageError->throw("argument to insert_one must be a single hashref, arrayref or Tie::IxHash");
     }
 
     # clone docs to add id and leave original unmodified
     if ( ref $doc eq 'ARRAY' ) {
-        MongoDB::UsageError->throw("array reference to insert must have key/value pairs")
+        MongoDB::UsageError->throw("array reference to insert_one must have key/value pairs")
           if @$doc % 2;
         $doc = Tie::IxHash->new(@$doc);
     }
@@ -253,6 +253,14 @@ sub execute {
     return $self->_client->send_write_op( $op );
 }
 
+#--------------------------------------------------------------------------#
+# Deprecated methods
+#--------------------------------------------------------------------------#
+
+BEGIN {
+    no warnings 'once';
+    *insert = \&insert_one;
+}
 
 __PACKAGE__->meta->make_immutable;
 
@@ -270,7 +278,7 @@ MongoDB::BulkWrite - MongoDB bulk write interface
 
 =head1 VERSION
 
-version v0.999.998.6
+version v0.999.999.1
 
 =head1 SYNOPSIS
 
@@ -279,7 +287,7 @@ version v0.999.998.6
 
     my $bulk = $collection->initialize_ordered_bulk_op;
 
-    $bulk->insert( $doc );
+    $bulk->insert_one( $doc );
     $bulk->find( $query )->upsert->replace_one( $doc )
     $bulk->find( $query )->update( $modification )
 
@@ -356,9 +364,9 @@ A query document is required.  Use an empty hashref for no criteria:
 
 An exception will be thrown on error.
 
-=head2 insert
+=head2 insert_one
 
-    $bulk->insert( $doc );
+    $bulk->insert_one( $doc );
 
 Queues a document for insertion when L</execute> is called.  The document may
 be a hash reference, an array reference (with balance key/value pairs) or a
@@ -426,11 +434,11 @@ David Golden <david@mongodb.com>
 
 =item *
 
-Mike Friedman <friedo@mongodb.com>
+Mike Friedman <friedo@friedo.com>
 
 =item *
 
-Kristina Chodorow <kristina@mongodb.com>
+Kristina Chodorow <k.chodorow@gmail.com>
 
 =item *
 
