@@ -19,7 +19,7 @@ package MongoDB::BulkWriteResult;
 # ABSTRACT: MongoDB bulk write result document
 
 use version;
-our $VERSION = 'v0.999.998.6'; # TRIAL
+our $VERSION = 'v0.999.999.1'; # TRIAL
 
 # empty superclass for backcompatibility; add a variable to the
 # package namespace so Perl thinks it's a real package
@@ -87,6 +87,11 @@ has modified_count => (
     default => undef,
 );
 
+sub has_modified_count {
+    my ($self) = @_;
+    return defined( $self->modified_count );
+}
+
 has op_count => (
     is      => 'ro',
     isa     => Num,
@@ -310,7 +315,7 @@ MongoDB::BulkWriteResult - MongoDB bulk write result document
 
 =head1 VERSION
 
-version v0.999.998.6
+version v0.999.999.1
 
 =head1 SYNOPSIS
 
@@ -355,6 +360,9 @@ This field is not available from legacy servers before version 2.6.
 If results are seen from a legacy server (or from a mongos proxying
 for a legacy server) this attribute will be C<undef>.
 
+You can call C<has_modified_count> to find out if this attribute is
+defined or not.
+
 =head2 upserted
 
 An array reference containing information about upserted documents (if any).
@@ -486,11 +494,11 @@ David Golden <david@mongodb.com>
 
 =item *
 
-Mike Friedman <friedo@mongodb.com>
+Mike Friedman <friedo@friedo.com>
 
 =item *
 
-Kristina Chodorow <kristina@mongodb.com>
+Kristina Chodorow <k.chodorow@gmail.com>
 
 =item *
 
