@@ -20,7 +20,7 @@ package MongoDB::Code;
 # ABSTRACT: JavaScript Code
 
 use version;
-our $VERSION = 'v0.999.998.6'; # TRIAL
+our $VERSION = 'v0.999.999.1'; # TRIAL
 
 #pod =head1 NAME
 #pod
@@ -74,7 +74,7 @@ MongoDB::Code - JavaScript Code
 
 =head1 VERSION
 
-version v0.999.998.6
+version v0.999.999.1
 
 =head1 NAME
 
@@ -100,11 +100,11 @@ David Golden <david@mongodb.com>
 
 =item *
 
-Mike Friedman <friedo@mongodb.com>
+Mike Friedman <friedo@friedo.com>
 
 =item *
 
-Kristina Chodorow <kristina@mongodb.com>
+Kristina Chodorow <k.chodorow@gmail.com>
 
 =item *
 
