@@ -20,9 +20,10 @@ package MongoDB::Collection;
 # ABSTRACT: A MongoDB Collection
 
 use version;
-our $VERSION = 'v0.999.998.6'; # TRIAL
+our $VERSION = 'v0.999.999.1'; # TRIAL
 
 use MongoDB::Error;
+use MongoDB::IndexView;
 use MongoDB::InsertManyResult;
 use MongoDB::QueryResult;
 use MongoDB::WriteConcern;
@@ -108,16 +109,35 @@ has write_concern => (
     coerce   => 1,
 );
 
+#pod =attr max_time_ms
+#pod
+#pod Specifies the default maximum amount of time in milliseconds that the
+#pod server should use for working on a query.
+#pod
+#pod B<Note>: this will only be used for server versions 2.6 or greater, as that
+#pod was when the C<$maxTimeMS> meta-operator was introduced.
+#pod
+#pod =cut
+
+has max_time_ms => (
+    is      => 'ro',
+    isa     => NonNegNum,
+    required => 1,
+);
+
 #pod =attr bson_codec
 #pod
 #pod An object that provides the C<encode_one> and C<decode_one> methods, such
-#pod as from L<MongoDB::BSON>.
+#pod as from L<MongoDB::BSON>.  It may be initialized with a hash reference that
+#pod will be coerced into a new MongoDB::BSON object.  By default it will be
+#pod inherited from a L<MongoDB::Database> object.
 #pod
 #pod =cut
 
 has bson_codec => (
     is       => 'ro',
     isa      => BSONCodec,
+    coerce   => 1,
     required => 1,
 );
 
@@ -172,6 +192,31 @@ sub _build__full_name {
     return "${db_name}.${name}";
 }
 
+#pod =method indexes
+#pod
+#pod     $indexes = $collection->indexes;
+#pod
+#pod     $collection->indexes->create_one( [ x => 1 ], { unique => 1 } );
+#pod     $collection->indexes->drop_all;
+#pod
+#pod Returns a L<MongoDB::IndexView> object for managing the indexes associated
+#pod with the collection.
+#pod
+#pod =cut
+
+has _indexes => (
+    is      => 'ro',
+    isa     => InstanceOf['MongoDB::IndexView'],
+    lazy    => 1,
+    reader  => 'indexes',
+    builder => '_build__indexes',
+);
+
+sub _build__indexes {
+    my ($self) = @_;
+    return MongoDB::IndexView->new( collection => $self );
+}
+
 #--------------------------------------------------------------------------#
 # public methods
 #--------------------------------------------------------------------------#
@@ -304,7 +349,7 @@ sub insert_many {
     $bulk->insert($_) for @$documents;
     my $res = $bulk->execute( $wc );
     return MongoDB::InsertManyResult->new(
-        acknowledged => $wc->is_safe,
+        acknowledged => $wc->is_acknowledged,
         inserted     => $res->inserted,
     );
 }
@@ -478,6 +523,49 @@ sub update_many {
     return $self->client->send_write_op( $op );
 }
 
+#pod =method save_one
+#pod
+#pod     $collection->save_one(
+#pod         {"_id" => MongoDB::OID->new, "author" => "joe"}
+#pod     );
+#pod     $post = $collection->find_one( {author => "joe"} );
+#pod
+#pod     $post->{phone} = "555-5555";
+#pod
+#pod     $collection->save_one( $post );
+#pod
+#pod Saves one document into the database, either replacing an existing one or
+#pod upserting a new one.  The document B<must> have an C<_id> field or an
+#pod exception will be thrown.
+#pod
+#pod The method returns a L<MongoDB::UpdateResult> object.
+#pod
+#pod Unlike an C<insert>, this method is idempotent and will not throw a
+#pod duplicate key exception from the C<_id> field.  (Other unique index
+#pod constraints could still be violated, resulting in an error.)
+#pod
+#pod Note: this method is merely syntactic sugar for a replace_one with upsert:
+#pod
+#pod     $collection->save_one( $doc );  # same as following replace_one:
+#pod     $collection->replace_one( { _id => $doc->{_id} }, $doc, { upsert => 1 } );
+#pod
+#pod =cut
+
+my $save_one_args;
+
+sub save_one {
+    $save_one_args ||= compile( Object, IxHash );
+    my ( $self, $document ) = $save_one_args->(@_);
+
+    if ( $document->EXISTS("_id") ) {
+        return $self->replace_one( { "_id" => $document->FETCH( "_id" ) },
+            $document, { upsert => true } );
+    }
+    else {
+        MongoDB::UsageError->throw("argument to save_one must have an '_id' field");
+    }
+}
+
 #pod =method find
 #pod
 #pod     $cursor = $coll->find( $filter );
@@ -505,7 +593,8 @@ sub update_many {
 #pod * C<limit> – the maximum number of documents to return.
 #pod * C<maxTimeMS> – the maximum amount of time to allow the query to run. If
 #pod   C<$maxTimeMS> also exists in the modifiers document, the C<maxTimeMS> field
-#pod   overwrites C<$maxTimeMS>.
+#pod   overwrites C<$maxTimeMS>. (Note, this will be ignored for servers before
+#pod   version 2.6.)
 #pod * C<modifiers> – a hash reference of L<query
 #pod   modifiers|http://docs.mongodb.org/manual/reference/operator/query-modifier/>
 #pod   modifying the output or behavior of a query.
@@ -547,6 +636,11 @@ sub find {
     # backwards compatible sort option for deprecated 'query' alias
     $options->{sort} = delete $options->{sort_by} if $options->{sort_by};
 
+    # possibly fallback to default maxTimeMS
+    if ( ! exists $options->{maxTimeMS} && $self->max_time_ms ) {
+        $options->{maxTimeMS} = $self->max_time_ms;
+    }
+
     # coerce to IxHash
     __ixhash($options, 'sort');
 
@@ -587,7 +681,7 @@ sub find {
 #pod
 #pod =for :list
 #pod * C<maxTimeMS> – the maximum amount of time in milliseconds to allow the
-#pod   command to run.
+#pod   command to run.  (Note, this will be ignored for servers before version 2.6.)
 #pod * C<sort> – an L<ordered document|/Ordered document> defining the order in which
 #pod   to return matching documents. If C<$orderby> also exists in the modifiers
 #pod   document, the sort field overwrites C<$orderby>.  See docs for
@@ -606,6 +700,12 @@ sub find_one {
         Optional [MaybeHashRef],
     );
     my ( $self, $filter, $projection, $options ) = $find_one_args->(@_);
+    $options ||= {};
+
+    # possibly fallback to default maxTimeMS
+    if ( ! exists $options->{maxTimeMS} && $self->max_time_ms ) {
+        $options->{maxTimeMS} = $self->max_time_ms;
+    }
 
     # coerce to IxHash
     __ixhash($options, 'sort');
@@ -637,7 +737,7 @@ sub find_one {
 #pod
 #pod =for :list
 #pod * C<maxTimeMS> – the maximum amount of time in milliseconds to allow the
-#pod   command to run.
+#pod   command to run.  (Note, this will be ignored for servers before version 2.6.)
 #pod * C<projection> - a hash reference defining fields to return. See "L<limit
 #pod   fields to
 #pod   return|http://docs.mongodb.org/manual/tutorial/project-fields-from-query-results/>"
@@ -656,6 +756,11 @@ sub find_one_and_delete {
     # rename projection -> fields
     $options->{fields} = delete $options->{projection} if exists $options->{projection};
 
+    # possibly fallback to default maxTimeMS
+    if ( ! exists $options->{maxTimeMS} && $self->max_time_ms ) {
+        $options->{maxTimeMS} = $self->max_time_ms;
+    }
+
     # coerce to IxHash
     __ixhash($options, 'sort');
 
@@ -724,7 +829,7 @@ sub find_one_and_replace {
 #pod
 #pod =for :list
 #pod * C<maxTimeMS> – the maximum amount of time in milliseconds to allow the
-#pod   command to run.
+#pod   command to run.  (Note, this will be ignored for servers before version 2.6.)
 #pod * C<projection> - a hash reference defining fields to return. See "L<limit
 #pod   fields to
 #pod   return|http://docs.mongodb.org/manual/tutorial/project-fields-from-query-results/>"
@@ -772,7 +877,7 @@ sub find_one_and_update {
 #pod * C<batchSize> – the number of documents to return per batch.
 #pod * C<explain> – if true, return a single document with execution information.
 #pod * C<maxTimeMS> – the maximum amount of time in milliseconds to allow the
-#pod   command to run.
+#pod   command to run.  (Note, this will be ignored for servers before version 2.6.)
 #pod
 #pod B<Note> MongoDB 2.6+ added the '$out' pipeline operator.  If this operator is
 #pod used to write aggregation results directly to a collection, an empty result
@@ -795,6 +900,11 @@ sub aggregate {
         $options->{$k} = ( $options->{$k} ? true : false ) if exists $options->{$k};
     }
 
+    # possibly fallback to default maxTimeMS
+    if ( ! exists $options->{maxTimeMS} && $self->max_time_ms ) {
+        $options->{maxTimeMS} = $self->max_time_ms;
+    }
+
     # read preferences are ignored if the last stage is $out
     my ($last_op) = keys %{ $pipeline->[-1] };
     my $read_pref = $last_op eq '$out' ? undef : $self->read_preference;
@@ -827,7 +937,7 @@ sub aggregate {
 #pod   must be a string, array reference, hash reference or L<Tie::IxHash> object.
 #pod * C<limit> – the maximum number of documents to count.
 #pod * C<maxTimeMS> – the maximum amount of time in milliseconds to allow the
-#pod   command to run.
+#pod   command to run.  (Note, this will be ignored for servers before version 2.6.)
 #pod * C<skip> – the number of documents to skip before counting documents.
 #pod
 #pod B<NOTE>: On a sharded cluster, C<count> can result in an inaccurate count if
@@ -846,17 +956,22 @@ sub count {
     $filter  ||= {};
     $options ||= {};
 
+    # possibly fallback to default maxTimeMS
+    if ( ! exists $options->{maxTimeMS} && $self->max_time_ms ) {
+        $options->{maxTimeMS} = $self->max_time_ms;
+    }
+
     # string is OK so we check ref, not just exists
     __ixhash($options, 'hint') if ref $options->{hint};
 
-    my $res = $self->database->run_command(
+    my $res = $self->_run_command(
         Tie::IxHash->new( count => $self->name, query => $filter, %$options ),
         $self->read_preference );
 
     return $res->{n};
 }
 
-#pod =method distinct 
+#pod =method distinct
 #pod
 #pod     $result = $coll->count( $fieldname );
 #pod     $result = $coll->count( $fieldname, $filter );
@@ -872,7 +987,7 @@ sub count {
 #pod
 #pod =for :list
 #pod * C<maxTimeMS> – the maximum amount of time in milliseconds to allow the
-#pod   command to run.
+#pod   command to run.  (Note, this will be ignored for servers before version 2.6.)
 #pod
 #pod See documentation for the L<distinct
 #pod command|http://docs.mongodb.org/manual/reference/command/distinct/> for
@@ -888,6 +1003,11 @@ sub distinct {
     $filter ||= {};
     $options ||= {};
 
+    # possibly fallback to default maxTimeMS
+    if ( ! exists $options->{maxTimeMS} && $self->max_time_ms ) {
+        $options->{maxTimeMS} = $self->max_time_ms;
+    }
+
     my $op = MongoDB::Op::_Distinct->new(
         db_name         => $self->database->name,
         coll_name       => $self->name,
@@ -980,200 +1100,14 @@ sub rename {
 
     my ($db, @collection_bits) = split(/\./, $fullname);
     my $collection = join('.', @collection_bits);
+
+    # this does NOT use our private _run_command method as it needs to run
+    # against a totally different database
     my $obj = $database->run_command([ 'renameCollection' => "$db.$collection", 'to' => "$db.$collectionname" ]);
 
     return $conn->get_database( $db )->get_collection( $collectionname );
 }
 
-
-#pod =method ensure_index
-#pod
-#pod     $collection->ensure_index( $keys );
-#pod     $collection->ensure_index( $keys, $options );
-#pod     $collection->ensure_index(["foo" => 1, "bar" => -1], { unique => 1 });
-#pod
-#pod Makes sure the given C<$keys> of this collection are indexed. C<$keys> can be
-#pod an array reference, hash reference, or C<Tie::IxHash>.  Array references or
-#pod C<Tie::IxHash> is preferred for multi-key indexes, so that the keys are in the
-#pod correct order.  1 creates an ascending index, -1 creates a descending index.
-#pod
-#pod If an optional C<$options> argument is provided, those options are passed
-#pod through to the database to modify index creation.  Typical options include:
-#pod
-#pod =for :list
-#pod * background – build the index in the background
-#pod * name – a name for the index; one will be generated if not provided
-#pod * unique – if true, inserting duplicates will fail
-#pod
-#pod See the MongoDB L<index documentation|http://docs.mongodb.org/manual/indexes/>
-#pod for more information on indexing and index options.
-#pod
-#pod Returns true on success and throws an exception on failure.
-#pod
-#pod Note: index creation can take longer than the network timeout, resulting
-#pod in an exception.  If this is a concern, consider setting the C<background>
-#pod option.
-#pod
-#pod =cut
-
-sub ensure_index {
-    my ( $self, $keys, $opts ) = @_;
-    MongoDB::UsageError->throw("ensure_index options must be a hash reference")
-      if $opts && !ref($opts) eq 'HASH';
-
-    $keys = Tie::IxHash->new(@$keys) if ref $keys eq 'ARRAY';
-    $opts = $self->_clean_index_options( $opts, $keys );
-
-    # always use safe write concern for index creation
-    my $wc =
-        $self->write_concern->is_safe
-      ? $self->write_concern
-      : MongoDB::WriteConcern->new;
-
-    my $op = MongoDB::Op::_CreateIndexes->new(
-        db_name       => $self->database->name,
-        coll_name     => $self->name,
-        bson_codec    => $self->bson_codec,
-        indexes       => [ { key => $keys, %$opts } ],
-        write_concern => $wc,
-    );
-
-    $self->client->send_write_op($op);
-
-    return 1;
-}
-
-#pod =method save($doc, $options)
-#pod
-#pod     $collection->save({"author" => "joe"});
-#pod     $post = $collection->find_one;
-#pod
-#pod     $post->{author} = {"name" => "joe", "id" => 123, "phone" => "555-5555"};
-#pod
-#pod     $collection->save( $post );
-#pod     $collection->save( $post, { safe => 1 } )
-#pod
-#pod Inserts a document into the database if it does not have an _id field, upserts
-#pod it if it does have an _id field.
-#pod
-#pod The return types for this function are a bit of a mess, as it will return the
-#pod _id if a new document was inserted, 1 if an upsert occurred, and croak if the
-#pod safe option was set and an error occurred.  You can also check if the save
-#pod succeeded by doing an unsafe save, then calling
-#pod L<MongoDB::Database/"last_error($options?)">.
-#pod
-#pod =cut
-
-my $legacy_save_args;
-sub save {
-    $legacy_save_args ||= compile( Object, IxHash, Optional[HashRef] );
-    my ($self, $doc, $options) = $legacy_save_args->(@_);
-
-    if ( $doc->EXISTS("_id") ) {
-        $options ||= {};
-        $options->{'upsert'} = boolean::true;
-        return $self->update( { "_id" => $doc->FETCH( ("_id") ) }, $doc, $options );
-    }
-    else {
-        return $self->insert( $doc, ( $options ? $options : () ) );
-    }
-}
-
-
-#pod =method validate
-#pod
-#pod     $collection->validate;
-#pod
-#pod Asks the server to validate this collection.
-#pod Returns a hash of the form:
-#pod
-#pod     {
-#pod         'ok' => '1',
-#pod         'ns' => 'foo.bar',
-#pod         'result' => info
-#pod     }
-#pod
-#pod where C<info> is a string of information
-#pod about the collection.
-#pod
-#pod =cut
-
-sub validate {
-    my ($self, $scan_data) = @_;
-    $scan_data = 0 unless defined $scan_data;
-    my $obj = $self->database->run_command({ validate => $self->name });
-}
-
-
-#pod =method drop_indexes
-#pod
-#pod     $collection->drop_indexes;
-#pod
-#pod Removes all indexes from this collection.
-#pod
-#pod =cut
-
-sub drop_indexes {
-    my ($self) = @_;
-    return $self->drop_index('*');
-}
-
-#pod =method drop_index ($index_name)
-#pod
-#pod     $collection->drop_index('foo_1');
-#pod
-#pod Removes an index called C<$index_name> from this collection.
-#pod Use C<MongoDB::Collection::get_indexes> to find the index name.
-#pod
-#pod =cut
-
-sub drop_index {
-    my ($self, $index_name) = @_;
-    return $self->database->run_command([
-        dropIndexes => $self->name,
-        index => $index_name,
-    ]);
-}
-
-#pod =method get_indexes
-#pod
-#pod     @indexes = $collection->get_indexes;
-#pod
-#pod Returns a list of all indexes of this collection.
-#pod Each index contains C<ns>, C<name>, and C<key>
-#pod fields of the form:
-#pod
-#pod     {
-#pod         'ns' => 'db_name.collection_name',
-#pod         'name' => 'index_name',
-#pod         'key' => {
-#pod             'key1' => dir1,
-#pod             'key2' => dir2,
-#pod             ...
-#pod             'keyN' => dirN
-#pod         }
-#pod     }
-#pod
-#pod where C<dirX> is 1 or -1, depending on if the
-#pod index is ascending or descending on that key.
-#pod
-#pod =cut
-
-sub get_indexes {
-    my ($self) = @_;
-
-    my $op = MongoDB::Op::_ListIndexes->new(
-        db_name    => $self->database->name,
-        coll_name  => $self->name,
-        client     => $self->client,
-        bson_codec => $self->bson_codec,
-    );
-
-    my $res = $self->client->send_read_op($op);
-
-    return $res->all;
-}
-
 #pod =method drop
 #pod
 #pod     $collection->drop;
@@ -1185,7 +1119,7 @@ sub get_indexes {
 sub drop {
     my ($self) = @_;
     try {
-        $self->database->run_command({ drop => $self->name });
+        $self->_run_command({ drop => $self->name });
     }
     catch {
         die $_ unless /ns not found/;
@@ -1324,7 +1258,7 @@ sub bulk_write {
 
         # handle inserts
         if ( $method eq 'insert_one' || $method eq 'insert_many' ) {
-            $bulk->insert($_) for @$args;
+            $bulk->insert_one($_) for @$args;
         }
         else {
             my ($filter, $doc, $options) = @$args;
@@ -1333,11 +1267,11 @@ sub bulk_write {
 
             # handle deletes
             if ( $method eq 'delete_one' ) {
-                $view->remove_one;
+                $view->delete_one;
                 next;
             }
             elsif ( $method eq 'delete_many' ) {
-                $view->remove;
+                $view->delete_many;
                 next;
             }
 
@@ -1352,7 +1286,7 @@ sub bulk_write {
                 $view->update_one($doc);
             }
             elsif ( $method eq 'update_many' ) {
-                $view->update($doc);
+                $view->update_many($doc);
             }
             else {
                 MongoDB::UsageError->throw("unknown bulk operation '$method'");
@@ -1391,6 +1325,11 @@ sub _find_one_and_update_or_replace {
     # rename projection -> fields
     $options->{fields} = delete $options->{projection} if exists $options->{projection};
 
+    # possibly fallback to default maxTimeMS
+    if ( ! exists $options->{maxTimeMS} && $self->max_time_ms ) {
+        $options->{maxTimeMS} = $self->max_time_ms;
+    }
+
     # coerce to IxHash
     __ixhash($options, 'sort');
 
@@ -1411,12 +1350,33 @@ sub _find_one_and_update_or_replace {
     return $self->_try_find_and_modify( \@command );
 }
 
+# we have a private _run_command rather than using the 'database' attribute
+# so that we're using our BSON codec and not the source database one
+sub _run_command {
+    my ( $self, $command, $read_pref ) = @_;
+
+    if ( $read_pref && ref($read_pref) eq 'HASH' ) {
+        $read_pref = MongoDB::ReadPreference->new($read_pref);
+    }
+
+    my $op = MongoDB::Op::_Command->new(
+        db_name         => $self->database->name,
+        query           => $command,
+        bson_codec      => $self->bson_codec,
+        ( $read_pref ? ( read_preference => $read_pref ) : () ),
+    );
+
+    my $obj = $self->client->send_read_op($op);
+
+    return $obj->output;
+}
+
 sub _try_find_and_modify {
     my ($self, $command) = @_;
     my $result;
     # XXX this ought to use our codec
     try {
-        $result = $self->database->run_command( $command );
+        $result = $self->_run_command( $command );
     }
     catch {
         die $_ unless $_ eq 'No matching object found';
@@ -1426,40 +1386,6 @@ sub _try_find_and_modify {
     return;
 }
 
-# old API allowed some snake_case options; some options must
-# be turned into booleans
-sub _clean_index_options {
-    my ( $self, $orig, $keys ) = @_;
-
-    # copy the original so we don't modify it
-    my $opts = { $orig ? %$orig : () };
-
-    # add name if not provided
-    $opts->{name} = __to_index_string($keys)
-      unless defined $opts->{name};
-
-    # safe is no more
-    delete $opts->{safe} if exists $opts->{safe};
-
-    # convert snake case
-    if ( exists $opts->{drop_dups} ) {
-        $opts->{dropDups} = delete $opts->{drop_dups};
-    }
-
-    # convert snake case and turn into an integer
-    if ( exists $opts->{expire_after_seconds} ) {
-        $opts->{expireAfterSeconds} = int( delete $opts->{expire_after_seconds} );
-    }
-
-    # convert some things to booleans
-    for my $k (qw/unique background sparse dropDups/) {
-        next unless exists $opts->{$k};
-        $opts->{$k} = boolean( $opts->{$k} );
-    }
-
-    return $opts;
-}
-
 #--------------------------------------------------------------------------#
 # utility function
 #--------------------------------------------------------------------------#
@@ -1483,33 +1409,6 @@ sub __ixhash {
     return;
 }
 
-# utility function to generate an index name by concatenating key/value pairs
-sub __to_index_string {
-    my $keys = shift;
-
-    my @name;
-    if (ref $keys eq 'ARRAY') {
-        @name = @$keys;
-    }
-    elsif (ref $keys eq 'HASH' ) {
-        @name = %$keys
-    }
-    elsif (ref $keys eq 'Tie::IxHash') {
-        my @ks = $keys->Keys;
-        my @vs = $keys->Values;
-
-        for (my $i=0; $i<$keys->Length; $i++) {
-            push @name, $ks[$i];
-            push @name, $vs[$i];
-        }
-    }
-    else {
-        MongoDB::UsageError->throw("expected Tie::IxHash, hash, or array reference for keys");
-    }
-
-    return join("_", @name);
-}
-
 #--------------------------------------------------------------------------#
 # Deprecated legacy methods
 #--------------------------------------------------------------------------#
@@ -1624,6 +1523,21 @@ sub update {
     };
 }
 
+my $legacy_save_args;
+sub save {
+    $legacy_save_args ||= compile( Object, IxHash, Optional[HashRef] );
+    my ($self, $doc, $options) = $legacy_save_args->(@_);
+
+    if ( $doc->EXISTS("_id") ) {
+        $options ||= {};
+        $options->{'upsert'} = boolean::true;
+        return $self->update( { "_id" => $doc->FETCH( ("_id") ) }, $doc, $options );
+    }
+    else {
+        return $self->insert( $doc, ( $options ? $options : () ) );
+    }
+}
+
 my $legacy_fam_args;
 sub find_and_modify {
     $legacy_fam_args ||= compile( Object, HashRef );
@@ -1651,6 +1565,125 @@ sub get_collection {
     return $self->database->get_collection($self->name.'.'.$coll);
 }
 
+sub ensure_index {
+    my ( $self, $keys, $opts ) = @_;
+    MongoDB::UsageError->throw("ensure_index options must be a hash reference")
+      if $opts && !ref($opts) eq 'HASH';
+
+    $keys = Tie::IxHash->new(@$keys) if ref $keys eq 'ARRAY';
+    $opts = $self->_clean_index_options( $opts, $keys );
+
+    # always use safe write concern for index creation
+    my $wc =
+        $self->write_concern->is_acknowledged
+      ? $self->write_concern
+      : MongoDB::WriteConcern->new;
+
+    my $op = MongoDB::Op::_CreateIndexes->new(
+        db_name       => $self->database->name,
+        coll_name     => $self->name,
+        bson_codec    => $self->bson_codec,
+        indexes       => [ { key => $keys, %$opts } ],
+        write_concern => $wc,
+    );
+
+    $self->client->send_write_op($op);
+
+    return 1;
+}
+
+sub _clean_index_options {
+    my ( $self, $orig, $keys ) = @_;
+
+    # copy the original so we don't modify it
+    my $opts = { $orig ? %$orig : () };
+
+    # add name if not provided
+    $opts->{name} = __to_index_string($keys)
+      unless defined $opts->{name};
+
+    # safe is no more
+    delete $opts->{safe} if exists $opts->{safe};
+
+    # convert snake case
+    if ( exists $opts->{drop_dups} ) {
+        $opts->{dropDups} = delete $opts->{drop_dups};
+    }
+
+    # convert snake case and turn into an integer
+    if ( exists $opts->{expire_after_seconds} ) {
+        $opts->{expireAfterSeconds} = int( delete $opts->{expire_after_seconds} );
+    }
+
+    # convert some things to booleans
+    for my $k (qw/unique background sparse dropDups/) {
+        next unless exists $opts->{$k};
+        $opts->{$k} = boolean( $opts->{$k} );
+    }
+
+    return $opts;
+}
+
+sub __to_index_string {
+    my $keys = shift;
+
+    my @name;
+    if (ref $keys eq 'ARRAY') {
+        @name = @$keys;
+    }
+    elsif (ref $keys eq 'HASH' ) {
+        @name = %$keys
+    }
+    elsif (ref $keys eq 'Tie::IxHash') {
+        my @ks = $keys->Keys;
+        my @vs = $keys->Values;
+
+        for (my $i=0; $i<$keys->Length; $i++) {
+            push @name, $ks[$i];
+            push @name, $vs[$i];
+        }
+    }
+    else {
+        MongoDB::UsageError->throw("expected Tie::IxHash, hash, or array reference for keys");
+    }
+
+    return join("_", @name);
+}
+
+sub get_indexes {
+    my ($self) = @_;
+
+    my $op = MongoDB::Op::_ListIndexes->new(
+        db_name    => $self->database->name,
+        coll_name  => $self->name,
+        client     => $self->client,
+        bson_codec => $self->bson_codec,
+    );
+
+    my $res = $self->client->send_read_op($op);
+
+    return $res->all;
+}
+
+sub drop_indexes {
+    my ($self) = @_;
+    return $self->drop_index('*');
+}
+
+sub drop_index {
+    my ($self, $index_name) = @_;
+    return $self->_run_command([
+        dropIndexes => $self->name,
+        index => $index_name,
+    ]);
+}
+
+sub validate {
+    my ($self, $scan_data) = @_;
+    $scan_data = 0 unless defined $scan_data;
+    my $obj = $self->_run_command({ validate => $self->name });
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -1665,7 +1698,7 @@ MongoDB::Collection - A MongoDB Collection
 
 =head1 VERSION
 
-version v0.999.998.6
+version v0.999.999.1
 
 =head1 SYNOPSIS
 
@@ -1777,10 +1810,20 @@ A L<MongoDB::WriteConcern> object.  It may be initialized with a hash
 reference that will be coerced into a new MongoDB::WriteConcern object.
 By default it will be inherited from a L<MongoDB::Database> object.
 
+=head2 max_time_ms
+
+Specifies the default maximum amount of time in milliseconds that the
+server should use for working on a query.
+
+B<Note>: this will only be used for server versions 2.6 or greater, as that
+was when the C<$maxTimeMS> meta-operator was introduced.
+
 =head2 bson_codec
 
 An object that provides the C<encode_one> and C<decode_one> methods, such
-as from L<MongoDB::BSON>.
+as from L<MongoDB::BSON>.  It may be initialized with a hash reference that
+will be coerced into a new MongoDB::BSON object.  By default it will be
+inherited from a L<MongoDB::Database> object.
 
 =head1 METHODS
 
@@ -1799,6 +1842,16 @@ Returns the full name of the collection, including the namespace of the
 database it's in prefixed with a dot character.  E.g. collection "foo" in
 database "test" would result in a C<full_name> of "test.foo".
 
+=head2 indexes
+
+    $indexes = $collection->indexes;
+
+    $collection->indexes->create_one( [ x => 1 ], { unique => 1 } );
+    $collection->indexes->drop_all;
+
+Returns a L<MongoDB::IndexView> object for managing the indexes associated
+with the collection.
+
 =head2 clone
 
     $coll2 = $coll1->clone( write_concern => { w => 2 } );
@@ -1923,6 +1976,32 @@ C<upsert>, which defaults to false.  If provided and true, a new document will
 be inserted by taking the filter document and applying the update document
 operations to it prior to insertion.
 
+=head2 save_one
+
+    $collection->save_one(
+        {"_id" => MongoDB::OID->new, "author" => "joe"}
+    );
+    $post = $collection->find_one( {author => "joe"} );
+
+    $post->{phone} = "555-5555";
+
+    $collection->save_one( $post );
+
+Saves one document into the database, either replacing an existing one or
+upserting a new one.  The document B<must> have an C<_id> field or an
+exception will be thrown.
+
+The method returns a L<MongoDB::UpdateResult> object.
+
+Unlike an C<insert>, this method is idempotent and will not throw a
+duplicate key exception from the C<_id> field.  (Other unique index
+constraints could still be violated, resulting in an error.)
+
+Note: this method is merely syntactic sugar for a replace_one with upsert:
+
+    $collection->save_one( $doc );  # same as following replace_one:
+    $collection->replace_one( { _id => $doc->{_id} }, $doc, { upsert => 1 } );
+
 =head2 find
 
     $cursor = $coll->find( $filter );
@@ -1962,7 +2041,7 @@ C<limit> – the maximum number of documents to return.
 
 =item *
 
-C<maxTimeMS> – the maximum amount of time to allow the query to run. If C<$maxTimeMS> also exists in the modifiers document, the C<maxTimeMS> field overwrites C<$maxTimeMS>.
+C<maxTimeMS> – the maximum amount of time to allow the query to run. If C<$maxTimeMS> also exists in the modifiers document, the C<maxTimeMS> field overwrites C<$maxTimeMS>. (Note, this will be ignored for servers before version 2.6.)
 
 =item *
 
@@ -2027,7 +2106,7 @@ include:
 
 =item *
 
-C<maxTimeMS> – the maximum amount of time in milliseconds to allow the command to run.
+C<maxTimeMS> – the maximum amount of time in milliseconds to allow the command to run.  (Note, this will be ignored for servers before version 2.6.)
 
 =item *
 
@@ -2052,7 +2131,7 @@ A hash reference of options may be provided. Valid keys include:
 
 =item *
 
-C<maxTimeMS> – the maximum amount of time in milliseconds to allow the command to run.
+C<maxTimeMS> – the maximum amount of time in milliseconds to allow the command to run.  (Note, this will be ignored for servers before version 2.6.)
 
 =item *
 
@@ -2119,7 +2198,7 @@ A hash reference of options may be provided. Valid keys include:
 
 =item *
 
-C<maxTimeMS> – the maximum amount of time in milliseconds to allow the command to run.
+C<maxTimeMS> – the maximum amount of time in milliseconds to allow the command to run.  (Note, this will be ignored for servers before version 2.6.)
 
 =item *
 
@@ -2174,7 +2253,7 @@ C<explain> – if true, return a single document with execution information.
 
 =item *
 
-C<maxTimeMS> – the maximum amount of time in milliseconds to allow the command to run.
+C<maxTimeMS> – the maximum amount of time in milliseconds to allow the command to run.  (Note, this will be ignored for servers before version 2.6.)
 
 =back
 
@@ -2208,7 +2287,7 @@ C<limit> – the maximum number of documents to count.
 
 =item *
 
-C<maxTimeMS> – the maximum amount of time in milliseconds to allow the command to run.
+C<maxTimeMS> – the maximum amount of time in milliseconds to allow the command to run.  (Note, this will be ignored for servers before version 2.6.)
 
 =item *
 
@@ -2222,7 +2301,7 @@ command
 documentation|http://docs.mongodb.org/manual/reference/command/count/#behavior>
 for details and a work-around using L</aggregate>.
 
-=head2 distinct 
+=head2 distinct
 
     $result = $coll->count( $fieldname );
     $result = $coll->count( $fieldname, $filter );
@@ -2240,7 +2319,7 @@ A hash reference of options may be provided. Valid keys include:
 
 =item *
 
-C<maxTimeMS> – the maximum amount of time in milliseconds to allow the command to run.
+C<maxTimeMS> – the maximum amount of time in milliseconds to allow the command to run.  (Note, this will be ignored for servers before version 2.6.)
 
 =back
 
@@ -2272,115 +2351,6 @@ name, this method will throw an exception.
 It returns a new L<MongoDB::Collection> object corresponding to the renamed
 collection.
 
-=head2 ensure_index
-
-    $collection->ensure_index( $keys );
-    $collection->ensure_index( $keys, $options );
-    $collection->ensure_index(["foo" => 1, "bar" => -1], { unique => 1 });
-
-Makes sure the given C<$keys> of this collection are indexed. C<$keys> can be
-an array reference, hash reference, or C<Tie::IxHash>.  Array references or
-C<Tie::IxHash> is preferred for multi-key indexes, so that the keys are in the
-correct order.  1 creates an ascending index, -1 creates a descending index.
-
-If an optional C<$options> argument is provided, those options are passed
-through to the database to modify index creation.  Typical options include:
-
-=over 4
-
-=item *
-
-background – build the index in the background
-
-=item *
-
-name – a name for the index; one will be generated if not provided
-
-=item *
-
-unique – if true, inserting duplicates will fail
-
-=back
-
-See the MongoDB L<index documentation|http://docs.mongodb.org/manual/indexes/>
-for more information on indexing and index options.
-
-Returns true on success and throws an exception on failure.
-
-Note: index creation can take longer than the network timeout, resulting
-in an exception.  If this is a concern, consider setting the C<background>
-option.
-
-=head2 save($doc, $options)
-
-    $collection->save({"author" => "joe"});
-    $post = $collection->find_one;
-
-    $post->{author} = {"name" => "joe", "id" => 123, "phone" => "555-5555"};
-
-    $collection->save( $post );
-    $collection->save( $post, { safe => 1 } )
-
-Inserts a document into the database if it does not have an _id field, upserts
-it if it does have an _id field.
-
-The return types for this function are a bit of a mess, as it will return the
-_id if a new document was inserted, 1 if an upsert occurred, and croak if the
-safe option was set and an error occurred.  You can also check if the save
-succeeded by doing an unsafe save, then calling
-L<MongoDB::Database/"last_error($options?)">.
-
-=head2 validate
-
-    $collection->validate;
-
-Asks the server to validate this collection.
-Returns a hash of the form:
-
-    {
-        'ok' => '1',
-        'ns' => 'foo.bar',
-        'result' => info
-    }
-
-where C<info> is a string of information
-about the collection.
-
-=head2 drop_indexes
-
-    $collection->drop_indexes;
-
-Removes all indexes from this collection.
-
-=head2 drop_index ($index_name)
-
-    $collection->drop_index('foo_1');
-
-Removes an index called C<$index_name> from this collection.
-Use C<MongoDB::Collection::get_indexes> to find the index name.
-
-=head2 get_indexes
-
-    @indexes = $collection->get_indexes;
-
-Returns a list of all indexes of this collection.
-Each index contains C<ns>, C<name>, and C<key>
-fields of the form:
-
-    {
-        'ns' => 'db_name.collection_name',
-        'name' => 'index_name',
-        'key' => {
-            'key1' => dir1,
-            'key2' => dir2,
-            ...
-            'keyN' => dirN
-        }
-    }
-
-where C<dirX> is 1 or -1, depending on if the
-index is ascending or descending on that key.
-
 =head2 drop
 
     $collection->drop;
@@ -2501,11 +2471,23 @@ remove
 
 update
 
+=item *
+
+save
+
 =back
 
 The C<get_collection> method is deprecated; it implied a 'subcollection'
 relationship that is purely notional.
 
+The C<ensure_index>, C<drop_indexes>, C<drop_index>, and C<get_index>
+methods are deprecated. The new L<MongoDB::IndexView> class is accessable
+through the C<indexes> method, and offer greater consistency in behavior
+across drivers.
+
+The C<validate> method is deprecated as the return value was inconsistent
+over time. Users who need it should execute it via C<run_command> instead.
+
 The methods still exist, but are no longer documented.  In a future version
 they will warn when used, then will eventually be removed.
 
@@ -2519,11 +2501,11 @@ David Golden <david@mongodb.com>
 
 =item *
 
-Mike Friedman <friedo@mongodb.com>
+Mike Friedman <friedo@friedo.com>
 
 =item *
 
-Kristina Chodorow <kristina@mongodb.com>
+Kristina Chodorow <k.chodorow@gmail.com>
 
 =item *
 
