@@ -20,7 +20,7 @@ package MongoDB::Cursor;
 # ABSTRACT: A lazy cursor for Mongo query results
 
 use version;
-our $VERSION = 'v0.999.998.6'; # TRIAL
+our $VERSION = 'v0.999.999.1'; # TRIAL
 
 use Moose;
 use MongoDB;
@@ -35,40 +35,6 @@ use Tie::IxHash;
 use Try::Tiny;
 use namespace::clean -except => 'meta';
 
-use constant {
-    CURSOR_ZERO => "\0" x 8,
-    FLAG_ZERO => "\0" x 4,
-};
-
-$MongoDB::Cursor::_request_id = int(rand(1000000));
-
-#pod =head1 GLOBAL VARIABLES
-#pod
-#pod =head2 slave_okay
-#pod
-#pod     $MongoDB::Cursor::slave_okay = 1;
-#pod
-#pod Whether it is okay to run queries on the slave.  Defaults to 0.
-#pod
-#pod =cut
-
-$MongoDB::Cursor::slave_okay = 0;
-
-#pod =head2 timeout
-#pod
-#pod B<Deprecated, use MongoDB::MongoClient::query_timeout instead.>
-#pod
-#pod How many milliseconds to wait for a response from the server.  Set to 30000
-#pod (30 seconds) by default.  -1 waits forever (or until TCP times out, which is
-#pod usually a long time).
-#pod
-#pod This value is overridden by C<MongoDB::MongoClient::query_timeout> and never
-#pod used.
-#pod
-#pod =cut
-
-$MongoDB::Cursor::timeout = 30000;
-
 #pod =attr started_iterating
 #pod
 #pod If this cursor has queried the database yet. Methods
@@ -318,7 +284,7 @@ sub skip {
 
 #pod =head2 snapshot
 #pod
-#pod     $cursor->snapshot;
+#pod     $cursor->snapshot(1);
 #pod
 #pod Uses snapshot mode for the query.  Snapshot mode assures no duplicates are
 #pod returned due an intervening write relocating a document.  Note that if an
@@ -331,14 +297,16 @@ sub skip {
 #pod
 #pod =cut
 
-# XXX this doesn't allow turning it off!  That's inconsistent
-# with the rest of the cursor API
 sub snapshot {
-    my ($self) = @_;
+    my ($self, $bool) = @_;
+
     MongoDB::UsageError->throw("cannot set snapshot after querying")
       if $self->started_iterating;
 
-    $self->query->modifiers->{'$snapshot'} = 1;
+    MongoDB::UsageError->throw("snapshot requires a defined, boolean argument")
+      unless defined $bool;
+
+    $self->query->modifiers->{'$snapshot'} = $bool;
     return $self;
 }
 
@@ -434,38 +402,6 @@ sub read_preference {
     return $self;
 }
 
-#pod =head2 slave_okay (DEPRECATED)
-#pod
-#pod     $cursor->slave_okay(1);
-#pod
-#pod If a query can be done on a slave database server.
-#pod
-#pod Boolean value, defaults to 0.
-#pod
-#pod Returns this cursor for chaining operations.
-#pod
-#pod =cut
-
-sub slave_okay {
-    my ($self, $value) = @_;
-    MongoDB::UsageError->throw("cannot set slave_ok after querying")
-      if $self->started_iterating;
-
-    if ( $value ) {
-        # if not 'primary', then slave_ok is already true, so leave alone
-        if ( $self->query->read_preference->mode eq 'primary' ) {
-            # secondaryPreferred is how mongos interpretes slave_ok
-            $self->query->read_preference('secondaryPreferred');
-        }
-    }
-    else {
-        $self->query->read_preference('primary');
-    }
-
-    # XXX returning self is an API change but more consistent with other cursor methods
-    return $self;
-}
-
 #pod =head1 QUERY INTROSPECTION AND RESET
 #pod
 #pod These methods run introspection methods on the query conditions and modifiers
@@ -498,48 +434,6 @@ sub explain {
     return $new_query->execute->next;
 }
 
-#pod =head2 count
-#pod
-#pod     my $num = $cursor->count;
-#pod     my $num = $cursor->skip(20)->count(1);
-#pod
-#pod Returns the number of document this query will return.  Optionally takes a
-#pod boolean parameter, indicating that the cursor's limit and skip fields should be
-#pod used in calculating the count.
-#pod
-#pod =cut
-
-sub count {
-    my ($self, $limit_skip) = @_;
-    # XXX deprecate this unintuitive API?
-
-    my $cmd = new Tie::IxHash(count => $self->query->coll_name);
-
-    $cmd->Push(query => $self->query->filter);
-
-    if ($limit_skip) {
-        $cmd->Push(limit => $self->query->limit) if $self->query->limit;
-        $cmd->Push(skip => $self->query->skip) if $self->query->skip;
-    }
-
-    if (my $hint = $self->query->modifiers->{'$hint'}) {
-        $cmd->Push(hint => $hint);
-    }
-
-    my $result = try {
-        my $db = $self->query->client->get_database( $self->query->db_name );
-        $db->run_command( $cmd, $self->query->read_preference );
-    }
-    catch {
-        # if there was an error, check if it was the "ns missing" one that means the
-        # collection hasn't been created or a real error.
-        die $_ unless /^ns missing/;
-    };
-
-    return $result ? $result->{n} : 0;
-}
-
-
 #pod =head1 QUERY ITERATION
 #pod
 #pod These methods allow you to iterate over results.
@@ -643,6 +537,60 @@ sub info {
     }
 }
 
+#--------------------------------------------------------------------------#
+# Deprecated methods
+#--------------------------------------------------------------------------#
+
+sub count {
+    my ($self, $limit_skip) = @_;
+    # XXX deprecate this unintuitive API?
+
+    my $cmd = new Tie::IxHash(count => $self->query->coll_name);
+
+    $cmd->Push(query => $self->query->filter);
+
+    if ($limit_skip) {
+        $cmd->Push(limit => $self->query->limit) if $self->query->limit;
+        $cmd->Push(skip => $self->query->skip) if $self->query->skip;
+    }
+
+    if (my $hint = $self->query->modifiers->{'$hint'}) {
+        $cmd->Push(hint => $hint);
+    }
+
+    my $result = try {
+        my $db = $self->query->client->get_database( $self->query->db_name );
+        $db->run_command( $cmd, $self->query->read_preference );
+    }
+    catch {
+        # if there was an error, check if it was the "ns missing" one that means the
+        # collection hasn't been created or a real error.
+        die $_ unless /^ns missing/;
+    };
+
+    return $result ? $result->{n} : 0;
+}
+
+sub slave_okay {
+    my ($self, $value) = @_;
+    MongoDB::UsageError->throw("cannot set slave_ok after querying")
+      if $self->started_iterating;
+
+    if ( $value ) {
+        # if not 'primary', then slave_ok is already true, so leave alone
+        if ( $self->query->read_preference->mode eq 'primary' ) {
+            # secondaryPreferred is how mongos interpretes slave_ok
+            $self->query->read_preference('secondaryPreferred');
+        }
+    }
+    else {
+        $self->query->read_preference('primary');
+    }
+
+    # XXX returning self is an API change but more consistent with other cursor methods
+    return $self;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -663,7 +611,7 @@ MongoDB::Cursor - A lazy cursor for Mongo query results
 
 =head1 VERSION
 
-version v0.999.998.6
+version v0.999.999.1
 
 =head1 SYNOPSIS
 
@@ -689,25 +637,6 @@ If this cursor has queried the database yet. Methods
 modifying the query will complain if they are called
 after the database is queried.
 
-=head1 GLOBAL VARIABLES
-
-=head2 slave_okay
-
-    $MongoDB::Cursor::slave_okay = 1;
-
-Whether it is okay to run queries on the slave.  Defaults to 0.
-
-=head2 timeout
-
-B<Deprecated, use MongoDB::MongoClient::query_timeout instead.>
-
-How many milliseconds to wait for a response from the server.  Set to 30000
-(30 seconds) by default.  -1 waits forever (or until TCP times out, which is
-usually a long time).
-
-This value is overridden by C<MongoDB::MongoClient::query_timeout> and never
-used.
-
 =head1 QUERY MODIFIERS
 
 These methods modify the query to be run.  An exception will be thrown if
@@ -823,7 +752,7 @@ Returns this cursor for chaining operations.
 
 =head2 snapshot
 
-    $cursor->snapshot;
+    $cursor->snapshot(1);
 
 Uses snapshot mode for the query.  Snapshot mode assures no duplicates are
 returned due an intervening write relocating a document.  Note that if an
@@ -870,16 +799,6 @@ documentation.
 
 Returns this cursor for chaining operations.
 
-=head2 slave_okay (DEPRECATED)
-
-    $cursor->slave_okay(1);
-
-If a query can be done on a slave database server.
-
-Boolean value, defaults to 0.
-
-Returns this cursor for chaining operations.
-
 =head1 QUERY INTROSPECTION AND RESET
 
 These methods run introspection methods on the query conditions and modifiers
@@ -896,15 +815,6 @@ the time in milliseconds the query took to execute.
 See also core documentation on explain:
 L<http://dochub.mongodb.org/core/explain>.
 
-=head2 count
-
-    my $num = $cursor->count;
-    my $num = $cursor->skip(20)->count(1);
-
-Returns the number of document this query will return.  Optionally takes a
-boolean parameter, indicating that the cursor's limit and skip fields should be
-used in calculating the count.
-
 =head1 QUERY ITERATION
 
 These methods allow you to iterate over results.
@@ -997,11 +907,11 @@ David Golden <david@mongodb.com>
 
 =item *
 
-Mike Friedman <friedo@mongodb.com>
+Mike Friedman <friedo@friedo.com>
 
 =item *
 
-Kristina Chodorow <kristina@mongodb.com>
+Kristina Chodorow <k.chodorow@gmail.com>
 
 =item *
 
