@@ -20,7 +20,7 @@ package MongoDB::Database;
 # ABSTRACT: A MongoDB Database
 
 use version;
-our $VERSION = 'v0.999.998.6'; # TRIAL
+our $VERSION = 'v0.999.999.1'; # TRIAL
 
 use MongoDB::CommandResult;
 use MongoDB::Error;
@@ -28,6 +28,7 @@ use MongoDB::GridFS;
 use MongoDB::Op::_ListCollections;
 use MongoDB::_Query;
 use MongoDB::_Types -types;
+use Type::Params qw/compile/;
 use Types::Standard -types;
 use Carp 'carp';
 use boolean;
@@ -84,16 +85,35 @@ has write_concern => (
     coerce   => 1,
 );
 
+#pod =attr max_time_ms
+#pod
+#pod Specifies the maximum amount of time in milliseconds that the server should use
+#pod for working on a query.
+#pod
+#pod B<Note>: this will only be used for server versions 2.6 or greater, as that
+#pod was when the C<$maxTimeMS> meta-operator was introduced.
+#pod
+#pod =cut
+
+has max_time_ms => (
+    is      => 'ro',
+    isa     => NonNegNum,
+    required => 1,
+);
+
 #pod =attr bson_codec
 #pod
-#pod An object that provides the C<encode_one> and C<decode_one> methods, such
-#pod as from L<MongoDB::BSON>.
+#pod An object that provides the C<encode_one> and C<decode_one> methods, such as
+#pod from L<MongoDB::BSON>.  It may be initialized with a hash reference that will
+#pod be coerced into a new MongoDB::BSON object.  By default it will be inherited
+#pod from a L<MongoDB::MongoClient> object.
 #pod
 #pod =cut
 
 has bson_codec => (
     is       => 'ro',
     isa      => BSONCodec,
+    coerce   => 1,
     required => 1,
 );
 
@@ -101,12 +121,73 @@ has bson_codec => (
 # methods
 #--------------------------------------------------------------------------#
 
+#pod =method list_collections
+#pod
+#pod     $result = $coll->list_collections( $filter );
+#pod     $result = $coll->list_collections( $filter, $options );
+#pod
+#pod Returns a L<MongoDB::QueryResult> object to iterate over collection description
+#pod documents.  These will contain C<name> and C<options> keys like so:
+#pod
+#pod     use boolean;
+#pod
+#pod     {
+#pod         name => "my_capped_collection",
+#pod         options => {
+#pod             capped => true,
+#pod             size => 10485760,
+#pod         }
+#pod     },
+#pod
+#pod An optional filter document may be provided, which cause only collection
+#pod description documents matching a filter expression to be returned.  See the
+#pod L<listCollections command
+#pod documentation|http://docs.mongodb.org/manual/reference/command/listCollections/>
+#pod for more details on filtering for specific collections.
+#pod
+#pod A hash reference of options may be provided. Valid keys include:
+#pod
+#pod =for :list
+#pod * C<batchSize> – the number of documents to return per batch.
+#pod * C<maxTimeMS> – the maximum amount of time in milliseconds to allow the
+#pod   command to run.  (Note, this will be ignored for servers before version 2.6.)
+#pod
+#pod =cut
+
+my $list_collections_args;
+
+sub list_collections {
+    $list_collections_args ||= compile( Object, Optional [IxHash], Optional [HashRef] );
+    my ( $self, $filter, $options ) = $list_collections_args->(@_);
+    $filter  ||= {};
+    $options ||= {};
+
+    # possibly fallback to default maxTimeMS
+    if ( ! exists $options->{maxTimeMS} && $self->max_time_ms ) {
+        $options->{maxTimeMS} = $self->max_time_ms;
+    }
+
+    my $op = MongoDB::Op::_ListCollections->new(
+        db_name    => $self->name,
+        client     => $self->_client,
+        bson_codec => $self->bson_codec,
+        filter     => $filter,
+        options    => $options,
+    );
+
+    return $self->_client->send_read_op($op);
+}
+
 #pod =method collection_names
 #pod
 #pod     my @collections = $database->collection_names;
 #pod
 #pod Returns the list of collections in this database.
 #pod
+#pod B<Warning:> if the number of collections is very large, this will return
+#pod a very large result.  Use L</list_collections> to iterate over collections
+#pod instead.
+#pod
 #pod =cut
 
 sub collection_names {
@@ -116,6 +197,7 @@ sub collection_names {
         db_name    => $self->name,
         client     => $self->_client,
         bson_codec => $self->bson_codec,
+        filter     => {},
     );
 
     my $res = $self->_client->send_read_op($op);
@@ -145,6 +227,7 @@ sub get_collection {
         read_preference => $self->read_preference,
         write_concern   => $self->write_concern,
         bson_codec      => $self->bson_codec,
+        max_time_ms     => $self->max_time_ms,
         ( $options ? %$options : () ),
         # not allowed to be overridden by options
         database => $self,
@@ -178,6 +261,8 @@ sub get_gridfs {
     return MongoDB::GridFS->new(
         read_preference => $self->read_preference,
         write_concern   => $self->write_concern,
+        max_time_ms     => $self->max_time_ms,
+        bson_codec      => $self->bson_codec,
         ( $options ? %$options : () ),
         # not allowed to be overridden by options
         _database => $self,
@@ -314,7 +399,7 @@ MongoDB::Database - A MongoDB Database
 
 =head1 VERSION
 
-version v0.999.998.6
+version v0.999.999.1
 
 =head1 SYNOPSIS
 
@@ -382,19 +467,71 @@ A L<MongoDB::WriteConcern> object.  It may be initialized with a hash
 reference that will be coerced into a new MongoDB::WriteConcern object.
 By default it will be inherited from a L<MongoDB::MongoClient> object.
 
+=head2 max_time_ms
+
+Specifies the maximum amount of time in milliseconds that the server should use
+for working on a query.
+
+B<Note>: this will only be used for server versions 2.6 or greater, as that
+was when the C<$maxTimeMS> meta-operator was introduced.
+
 =head2 bson_codec
 
-An object that provides the C<encode_one> and C<decode_one> methods, such
-as from L<MongoDB::BSON>.
+An object that provides the C<encode_one> and C<decode_one> methods, such as
+from L<MongoDB::BSON>.  It may be initialized with a hash reference that will
+be coerced into a new MongoDB::BSON object.  By default it will be inherited
+from a L<MongoDB::MongoClient> object.
 
 =head1 METHODS
 
+=head2 list_collections
+
+    $result = $coll->list_collections( $filter );
+    $result = $coll->list_collections( $filter, $options );
+
+Returns a L<MongoDB::QueryResult> object to iterate over collection description
+documents.  These will contain C<name> and C<options> keys like so:
+
+    use boolean;
+
+    {
+        name => "my_capped_collection",
+        options => {
+            capped => true,
+            size => 10485760,
+        }
+    },
+
+An optional filter document may be provided, which cause only collection
+description documents matching a filter expression to be returned.  See the
+L<listCollections command
+documentation|http://docs.mongodb.org/manual/reference/command/listCollections/>
+for more details on filtering for specific collections.
+
+A hash reference of options may be provided. Valid keys include:
+
+=over 4
+
+=item *
+
+C<batchSize> – the number of documents to return per batch.
+
+=item *
+
+C<maxTimeMS> – the maximum amount of time in milliseconds to allow the command to run.  (Note, this will be ignored for servers before version 2.6.)
+
+=back
+
 =head2 collection_names
 
     my @collections = $database->collection_names;
 
 Returns the list of collections in this database.
 
+B<Warning:> if the number of collections is very large, this will return
+a very large result.  Use L</list_collections> to iterate over collections
+instead.
+
 =head2 get_collection, coll
 
     my $collection = $database->get_collection('foo');
@@ -504,11 +641,11 @@ David Golden <david@mongodb.com>
 
 =item *
 
-Mike Friedman <friedo@mongodb.com>
+Mike Friedman <friedo@friedo.com>
 
 =item *
 
-Kristina Chodorow <kristina@mongodb.com>
+Kristina Chodorow <k.chodorow@gmail.com>
 
 =item *
 
