@@ -22,7 +22,7 @@ package MongoDB::Error;
 # ABSTRACT: MongoDB Driver Error classes
 
 use version;
-our $VERSION = 'v0.999.998.6'; # TRIAL
+our $VERSION = 'v0.999.999.1'; # TRIAL
 
 use Moose;
 use Carp;
@@ -272,7 +272,7 @@ MongoDB::Error - MongoDB Driver Error classes
 
 =head1 VERSION
 
-version v0.999.998.6
+version v0.999.999.1
 
 =head1 SYNOPSIS
 
@@ -538,11 +538,11 @@ David Golden <david@mongodb.com>
 
 =item *
 
-Mike Friedman <friedo@mongodb.com>
+Mike Friedman <friedo@friedo.com>
 
 =item *
 
-Kristina Chodorow <kristina@mongodb.com>
+Kristina Chodorow <k.chodorow@gmail.com>
 
 =item *
 
