@@ -20,7 +20,7 @@ package MongoDB::GridFS;
 # ABSTRACT: A file storage utility
 
 use version;
-our $VERSION = 'v0.999.998.6'; # TRIAL
+our $VERSION = 'v0.999.999.1'; # TRIAL
 
 use MongoDB::GridFS::File;
 use DateTime 0.78; # drops dependency on bug-prone Math::Round
@@ -77,6 +77,38 @@ has write_concern => (
     coerce   => 1,
 );
 
+#pod =attr max_time_ms
+#pod
+#pod Specifies the default maximum amount of time in milliseconds that the
+#pod server should use for working on a query.
+#pod
+#pod B<Note>: this will only be used for server versions 2.6 or greater, as that
+#pod was when the C<$maxTimeMS> meta-operator was introduced.
+#pod
+#pod =cut
+
+has max_time_ms => (
+    is      => 'ro',
+    isa     => NonNegNum,
+    required => 1,
+);
+
+#pod =attr bson_codec
+#pod
+#pod An object that provides the C<encode_one> and C<decode_one> methods, such
+#pod as from L<MongoDB::BSON>.  It may be initialized with a hash reference that
+#pod will be coerced into a new MongoDB::BSON object.  By default it will be
+#pod inherited from a L<MongoDB::Database> object.
+#pod
+#pod =cut
+
+has bson_codec => (
+    is       => 'ro',
+    isa      => BSONCodec,
+    coerce   => 1,
+    required => 1,
+);
+
 #pod =attr prefix
 #pod
 #pod The prefix used for the collections.  Defaults to "fs".
@@ -101,7 +133,9 @@ sub _build_files {
         $self->prefix . '.files',
         {
             read_preference => $self->read_preference,
-            write_concern   => $self->write_concern
+            write_concern   => $self->write_concern,
+            max_time_ms     => $self->max_time_ms,
+            bson_codec      => $self->bson_codec,
         }
     );
     return $coll;
@@ -119,7 +153,8 @@ sub _build_chunks {
         $self->prefix . '.chunks',
         {
             read_preference => $self->read_preference,
-            write_concern   => $self->write_concern
+            write_concern   => $self->write_concern,
+            max_time_ms     => $self->max_time_ms,
         }
     );
     return $coll;
@@ -336,7 +371,7 @@ sub insert {
 
     my %copy = %{$metadata};
     # compare the md5 hashes
-    if ($files->write_concern->is_safe) {
+    if ($files->write_concern->is_acknowledged) {
         # get an md5 hash for the file. set the retry flag to 'true' incase the 
         # database, collection, or indexes are missing. That way we can recreate them 
         # retry the md5 calc.
@@ -413,7 +448,7 @@ sub _dynamic_write_concern {
         return $wc;
     }
     elsif ( $opts->{safe} ) {
-        return $wc->is_safe ? $wc : MongoDB::WriteConcern->new( w => 1 );
+        return $wc->is_acknowledged ? $wc : MongoDB::WriteConcern->new( w => 1 );
     }
     else {
         return MongoDB::WriteConcern->new( w => 0 );
@@ -436,7 +471,7 @@ MongoDB::GridFS - A file storage utility
 
 =head1 VERSION
 
-version v0.999.998.6
+version v0.999.999.1
 
 =head1 SYNOPSIS
 
@@ -506,6 +541,21 @@ A L<MongoDB::WriteConcern> object.  It may be initialized with a hash
 reference that will be coerced into a new MongoDB::WriteConcern object.
 By default it will be inherited from a L<MongoDB::Database> object.
 
+=head2 max_time_ms
+
+Specifies the default maximum amount of time in milliseconds that the
+server should use for working on a query.
+
+B<Note>: this will only be used for server versions 2.6 or greater, as that
+was when the C<$maxTimeMS> meta-operator was introduced.
+
+=head2 bson_codec
+
+An object that provides the C<encode_one> and C<decode_one> methods, such
+as from L<MongoDB::BSON>.  It may be initialized with a hash reference that
+will be coerced into a new MongoDB::BSON object.  By default it will be
+inherited from a L<MongoDB::Database> object.
+
 =head2 prefix
 
 The prefix used for the collections.  Defaults to "fs".
@@ -632,11 +682,11 @@ David Golden <david@mongodb.com>
 
 =item *
 
-Mike Friedman <friedo@mongodb.com>
+Mike Friedman <friedo@friedo.com>
 
 =item *
 
-Kristina Chodorow <kristina@mongodb.com>
+Kristina Chodorow <k.chodorow@gmail.com>
 
 =item *
 
