@@ -20,7 +20,7 @@ package MongoDB::Op::_CreateIndexes;
 # or a MongoDB::InsertManyResult, depending on the server version
 
 use version;
-our $VERSION = 'v0.999.998.6'; # TRIAL
+our $VERSION = 'v0.999.999.1'; # TRIAL
 
 use Moose;
 
@@ -82,7 +82,7 @@ sub _command_create_indexes {
     my $res = $self->_send_command( $link, $cmd );
 
     return MongoDB::CommandResult->new(
-        output => $self->write_concern->is_safe ? $res : { ok => 1 },
+        output => $self->write_concern->is_acknowledged ? $res : { ok => 1 },
         address => $link->address,
     );
 }
