@@ -19,8 +19,9 @@ package MongoDB::QueryResult;
 # ABSTRACT: An iterator for Mongo query results
 
 use version;
-our $VERSION = 'v0.999.998.6'; # TRIAL
+our $VERSION = 'v0.999.999.1'; # TRIAL
 
+use Config;
 use Moose;
 use MongoDB::Error;
 use MongoDB::Op::_GetMore;
@@ -29,7 +30,10 @@ use MongoDB::_Types -types;
 use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
-use constant { CURSOR_ZERO => "\0" x 8, };
+use constant {
+    CURSOR_ZERO => "\0" x 8,
+    HAS_INT64 => $Config{use64bitint},
+};
 
 with 'MongoDB::Role::_Cursor';
 
@@ -295,11 +299,17 @@ sub _pack_cursor_id {
         $cursor_id = pack( "H*", $as_hex );                        # packed big-endian
         $cursor_id = reverse($cursor_id);                          # reverse to little-endian
     }
-    else {
+    elsif (HAS_INT64) {
         # pack doesn't have endianness modifiers before perl 5.10.
         # We die during configuration on big-endian platforms on 5.8
         $cursor_id = pack( $] lt '5.010' ? "q" : "q<", $cursor_id );
     }
+    else {
+        # we on 32-bit perl *and* have a cursor ID that fits in 32 bits,
+        # so pack it as long and pad out to a quad
+        $cursor_id = pack( $] lt '5.010' ? "l" : "l<", $cursor_id ) . ( "\0" x 4 );
+    }
+
     return $cursor_id;
 }
 
@@ -362,7 +372,7 @@ MongoDB::QueryResult - An iterator for Mongo query results
 
 =head1 VERSION
 
-version v0.999.998.6
+version v0.999.999.1
 
 =head1 SYNOPSIS
 
@@ -440,11 +450,11 @@ David Golden <david@mongodb.com>
 
 =item *
 
-Mike Friedman <friedo@mongodb.com>
+Mike Friedman <friedo@friedo.com>
 
 =item *
 
-Kristina Chodorow <kristina@mongodb.com>
+Kristina Chodorow <k.chodorow@gmail.com>
 
 =item *
 
