@@ -19,7 +19,7 @@ package MongoDB::UpdateResult;
 # ABSTRACT: MongoDB update result object
 
 use version;
-our $VERSION = 'v0.999.998.6'; # TRIAL
+our $VERSION = 'v0.999.999.1'; # TRIAL
 
 use Moose;
 use MongoDB::_Types -types;
@@ -53,6 +53,9 @@ has matched_count => (
 #pod from MongoDB version 2.6 or later.  It will return C<undef> from earlier
 #pod servers.
 #pod
+#pod You can call C<has_modified_count> to find out if this attribute is
+#pod defined or not.
+#pod
 #pod =cut
 
 has modified_count => (
@@ -60,6 +63,11 @@ has modified_count => (
     isa     => Maybe[Num],
 );
 
+sub has_modified_count {
+    my ($self) = @_;
+    return defined( $self->modified_count );
+}
+
 #pod =attr upserted_id
 #pod
 #pod The identifier of the inserted document if an upsert took place.  If
@@ -108,7 +116,7 @@ MongoDB::UpdateResult - MongoDB update result object
 
 =head1 VERSION
 
-version v0.999.998.6
+version v0.999.999.1
 
 =head1 SYNOPSIS
 
@@ -139,6 +147,9 @@ The number of documents that were modified.  Note: this is only available
 from MongoDB version 2.6 or later.  It will return C<undef> from earlier
 servers.
 
+You can call C<has_modified_count> to find out if this attribute is
+defined or not.
+
 =head2 upserted_id
 
 The identifier of the inserted document if an upsert took place.  If
@@ -170,11 +181,11 @@ David Golden <david@mongodb.com>
 
 =item *
 
-Mike Friedman <friedo@mongodb.com>
+Mike Friedman <friedo@friedo.com>
 
 =item *
 
-Kristina Chodorow <kristina@mongodb.com>
+Kristina Chodorow <k.chodorow@gmail.com>
 
 =item *
 
