@@ -19,7 +19,7 @@ package MongoDB::WriteConcern;
 # ABSTRACT: Encapsulate and validate a write concern
 
 use version;
-our $VERSION = 'v0.999.998.6'; # TRIAL
+our $VERSION = 'v0.999.999.1'; # TRIAL
 
 use Moose;
 use MongoDB::Error;
@@ -72,12 +72,12 @@ has j => (
     predicate => '_has_j',
 );
 
-has _is_safe => (
+has _is_acknowledged => (
     is      => 'ro',
     isa     => Bool,
     lazy    => 1,
-    reader  => 'is_safe',
-    builder => '_build_is_safe',
+    reader  => 'is_acknowledged',
+    builder => '_build_is_acknowledged',
 );
 
 has _as_struct => (
@@ -88,9 +88,9 @@ has _as_struct => (
     builder => '_build_as_struct',
 );
 
-sub _build_is_safe {
+sub _build_is_acknowledged {
     my ($self) = @_;
-    return !!( $self->j || $self->_w_is_safe );
+    return !!( $self->j || $self->_w_is_acknowledged );
 }
 
 sub _build_as_struct {
@@ -104,13 +104,13 @@ sub _build_as_struct {
 
 sub BUILD {
     my ($self) = @_;
-    if ( ! $self->_w_is_safe && $self->j ) {
+    if ( ! $self->_w_is_acknowledged && $self->j ) {
         MongoDB::UsageError->throw("can't use write concern w=0 with j=" . $self->j );
     }
     return;
 }
 
-sub _w_is_safe {
+sub _w_is_acknowledged {
     my ($self) = @_;
     return $self->_has_w
       && ( looks_like_number( $self->w ) ? $self->w > 0 : length $self->w );
@@ -130,7 +130,7 @@ MongoDB::WriteConcern - Encapsulate and validate a write concern
 
 =head1 VERSION
 
-version v0.999.998.6
+version v0.999.999.1
 
 =head1 SYNOPSIS
 
@@ -178,11 +178,11 @@ David Golden <david@mongodb.com>
 
 =item *
 
-Mike Friedman <friedo@mongodb.com>
+Mike Friedman <friedo@friedo.com>
 
 =item *
 
-Kristina Chodorow <kristina@mongodb.com>
+Kristina Chodorow <k.chodorow@gmail.com>
 
 =item *
 
