@@ -19,7 +19,7 @@ package MongoDB::_Query;
 # Encapsulate query structure and modification
 
 use version;
-our $VERSION = 'v0.999.998.6'; # TRIAL
+our $VERSION = 'v0.999.999.1'; # TRIAL
 
 use Moose;
 use MongoDB::_Types -types;
@@ -150,7 +150,7 @@ has sort => (
 );
 
 sub as_query_op {
-    my ($self) = @_;
+    my ( $self, $extra_params ) = @_;
 
     # construct query doc from filter, attributes and modifiers hash
     my $query = Tie::IxHash->new( '$query' => $self->filter );
@@ -160,11 +160,18 @@ sub as_query_op {
         $query->STORE( $k, $v );
     }
 
-    # if these exists, they overwrite any earlier modifers
-    for my $k (qw/maxTimeMS comment/) {
-        next unless my $v = $self->$k;
-        $query->STORE( "\$$k", $v );
+    # if comment exists, it overwrites any earlier modifers
+    if ( my $v = $self->comment ) {
+        $query->STORE( '$comment' => $v );
     }
+
+    # if maxTimeMS exists, it overwrites any earlier modifers
+    if ( my $v = $self->maxTimeMS ) {
+        # omit for $cmd* queries
+        $query->STORE( '$maxTimeMS' => $v )
+          unless $self->coll_name =~ /\A\$cmd/;
+    }
+
     $query->STORE( '$orderby', $self->sort ) if $self->sort->Keys;
 
     # if no modifers were added and there is no 'query' key in '$query'
@@ -195,6 +202,7 @@ sub as_query_op {
         limit       => $self->limit,
         skip        => $self->skip,
         query_flags => $query_flags,
+        ( $extra_params ? %$extra_params : () ),
     );
 }
 
