@@ -17,7 +17,7 @@
 package MongoDB::_Server;
 
 use version;
-our $VERSION = 'v0.999.998.6'; # TRIAL
+our $VERSION = 'v0.999.999.1'; # TRIAL
 
 use Moose;
 use MongoDB::_Types -types;
@@ -188,6 +188,20 @@ sub _build_is_available {
     return $self->type eq none(qw/Unknown PossiblePrimary/);
 }
 
+has is_readable => (
+    is      => 'ro',
+    isa     => Bool,
+    lazy    => 1,
+    builder => "_build_is_readable",
+);
+
+# any of these can take reads. Topologies will screen inappropriate
+# ones out. E.g. "Standalone" won't be found in a replica set topology.
+sub _build_is_readable {
+    my ($self) = @_;
+    return $self->type eq any(qw/Standalone RSPrimary RSSecondary Mongos/);
+}
+
 has is_writable => (
     is      => 'ro',
     isa     => Bool,
@@ -234,6 +248,17 @@ sub status_string {
     }
 }
 
+sub status_struct {
+    my ($self) = @_;
+    my $info = {
+        address => $self->address,
+        type    => $self->type
+    };
+    $info->{error} = $self->error         if $self->error;
+    $info->{tags}  = { %{ $self->tags } } if %{ $self->tags };
+    return $info;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
