@@ -17,7 +17,7 @@
 package MongoDB::_Topology;
 
 use version;
-our $VERSION = 'v0.999.998.6'; # TRIAL
+our $VERSION = 'v0.999.999.1'; # TRIAL
 
 use Moose;
 use MongoDB::BSON;
@@ -171,8 +171,7 @@ sub BUILD {
     my ($self) = @_;
     my $type = $self->type;
 
-    if ( my $set_name = $self->uri->options->{replicaSet} ) {
-        $self->_set_replica_set_name($set_name);
+    if ( my $set_name = $self->replica_set_name ) {
         if ( $type eq 'Single' || $type eq 'ReplicaSetNoPrimary' ) {
             # these are valid, so nothing to do here
         }
@@ -311,6 +310,28 @@ sub scan_all_servers {
     return;
 }
 
+sub status_struct {
+    my ($self) = @_;
+    my $status = { topology_type => $self->type, };
+    $status->{replica_set_name} = $self->replica_set_name if $self->replica_set_name;
+
+    # convert from [sec, microsec] array to floating point
+    my $lst = $self->last_scan_time;
+    $status->{last_scan_time} = $lst->[0] + $lst->[1] / 1e6;
+
+    my $rtt_hash = $self->rtt_ewma_ms;
+    my $ss = $status->{servers} = [];
+    for my $server ( $self->all_servers ) {
+        my $addr = $server->address;
+        my $server_struct = $server->status_struct;
+        if ( defined $rtt_hash->{$addr} ) {
+            $server_struct->{ewma_rtt_ms} = $rtt_hash->{$addr};
+        }
+        push @$ss, $server_struct;
+    }
+    return $status;
+}
+
 #--------------------------------------------------------------------------#
 # private methods
 #--------------------------------------------------------------------------#
@@ -593,6 +614,10 @@ sub _update_topology_from_link {
             query      => [ ismaster => 1 ],
             bson_codec => $self->bson_codec,
         );
+        # just for this command, use connect timeout as socket timeout;
+        # this violates encapsulation, but requires less API modification
+        # to support this specific exception to the socket timeout
+        local $link->{socket_timeout} = $link->{connect_timeout};
         $op->execute( $link )->output;
     }
     catch {
