@@ -17,7 +17,7 @@
 package MongoDB::_URI;
 
 use version;
-our $VERSION = 'v0.999.998.6'; # TRIAL
+our $VERSION = 'v0.999.999.1'; # TRIAL
 
 use Moose;
 use MongoDB::Error;
@@ -35,16 +35,14 @@ has uri => (
 
 has username => (
     is => 'ro',
-    isa => Str,
+    isa => Any,
     writer => '_set_username',
-    default => '',
 );
 
 has password => (
     is => 'ro',
-    isa => Str,
+    isa => Any,
     writer => '_set_password',
-    default => '',
 );
 
 has db_name => (
@@ -68,6 +66,36 @@ has hostpairs => (
     default => sub { [] },
 );
 
+has valid_options => (
+    is => 'ro',
+    isa => HashRef,
+    builder => '_build_valid_options',
+);
+
+sub _build_valid_options {
+    return {
+        map { lc($_) => 1 } qw(
+            authMechanism
+            authMechanismProperties
+            connectTimeoutMS
+            connect
+            heartbeatFrequencyMS
+            journal
+            localThresholdMS
+            maxTimeMS
+            readPreference
+            readPreferenceTags
+            replicaSet
+            serverSelectionTimeoutMS
+            socketCheckIntervalMS
+            socketTimeoutMS
+            ssl
+            w
+            wTimeoutMS
+        )
+    };
+}
+
 sub _unescape_all {
     my $str = shift;
     return '' unless defined $str;
@@ -75,13 +103,13 @@ sub _unescape_all {
     return $str;
 }
 
-sub _parse_tag_set {
-    my ($string) = @_;
+sub _parse_doc {
+    my ($name, $string) = @_;
     my $set = {};
     for my $tag ( split /,/, $string ) {
         if ( $tag =~ /\S/ ) {
             my @kv = map { s{^\s*}{}; s{\s*$}{}; $_ } split /:/, $tag, 2;
-            MongoDB::UsageError->throw("readPreferenceTagSet '$tag' is not a key:value pair")
+            MongoDB::UsageError->throw("in option '$name', '$tag' is not a key:value pair")
               unless @kv == 2;
             $set->{$kv[0]} = $kv[1];
         }
@@ -112,24 +140,37 @@ sub BUILD {
         ];
 
         if ( defined $result{options} ) {
+            my $valid = $self->valid_options;
             my %parsed;
             for my $opt ( split '&', $result{options} ) {
                 my @kv = split '=', $opt;
                 push @kv, '' if @kv == 1;
                 MongoDB::UsageError->throw("expected key value pair") unless @kv == 2;
                 my ($k, $v) = map { _unescape_all($_) } @kv;
-                if ( $k eq 'readPreferenceTags' ) {
-                    $parsed{$k} ||= [];
-                    push @{$parsed{$k}}, _parse_tag_set($v);
+                # connection string spec calls for case normalization
+                (my $lc_k = $k) =~ tr[A-Z][a-z];
+                if ( !$valid->{$lc_k} ) {
+                    warn "Unsupported option '$k' in URI $uri\n";
+                    next;
+                }
+                if ( $lc_k eq 'authmechanismproperties' ) {
+                    $parsed{$lc_k} = _parse_doc($k,$v);
+                }
+                elsif ( $lc_k eq 'readpreferencetags' ) {
+                    $parsed{$lc_k} ||= [];
+                    push @{$parsed{$lc_k}}, _parse_doc($k,$v);
+                }
+                elsif ( $lc_k eq 'ssl' || $lc_k eq 'journal' ) {
+                    $parsed{$lc_k} = __str_to_bool($k, $v);
                 }
                 else {
-                    $parsed{$k} = $v;
+                    $parsed{$lc_k} = $v;
                 }
             }
             $result{options} = \%parsed;
         }
 
-        delete $result{username} unless defined $result{username} && length $result{username};
+        delete $result{username} unless defined $result{username};
         delete $result{password} unless defined $result{password}; # can be empty string
         delete $result{db_name} unless defined $result{db_name} && length $result{db_name};
     }
@@ -145,6 +186,16 @@ sub BUILD {
     return;
 }
 
+sub __str_to_bool {
+    my ($k, $str) = @_;
+    MongoDB::UsageError->throw("cannot convert undef to bool for key '$k'")
+      unless defined $str;
+    # check for "true" and "false" (case-insensitively)
+    my $ret = $str eq "true" ? 1 : $str eq "false" ? 0 : undef;
+    return $ret if defined $ret;
+    MongoDB::UsageError->throw("expected boolean string 'true' or 'false' for key '$k' but instead received '$str'");
+}
+
 use overload
     '""' => sub { $_[0]->uri },
     'fallback' => 1;
