@@ -19,10 +19,30 @@
 #include "perl.h"
 #include "XSUB.h"
 #include "regcomp.h"
+#include "string.h"
 
 /* load after other Perl headers */
 #include "ppport.h"
 
+/* adapted from perl.h and must come after it */
+#if !defined(Strtoll)
+#    ifdef __hpux
+#        define Strtoll __strtoll
+#    endif
+#    ifdef WIN64
+#        define Strtoll _strtoi64
+#    endif
+#    if !defined(Strtoll) && defined(HAS_STRTOLL)
+#        define Strtoll strtoll
+#    endif
+#    if !defined(Strtoll) && defined(HAS_STRTOQ)
+#        define Strtoll strtoq
+#    endif
+#    if !defined(Strtoll)
+#        error strtoll not available
+#    endif
+#endif
+
 /* whether to add an _id field */
 #define PREP 1
 #define NO_PREP 0
@@ -60,7 +80,6 @@ typedef struct _stackette {
     (((svp = hv_fetchs(h, k, FALSE)) && *svp) ? *svp : 0)
 
 #include "perl_mongo.h"
-#include "string.h"
 
 /* perl call helpers
  *
@@ -568,13 +587,13 @@ sv_to_bson_elem (bson_t * bson, const char * in_key, SV *sv, HV *opts, stackette
     if (SvGMAGICAL(sv)) {
       mg_get(sv);
     }
-    else {
-      bson_append_null(bson, key, -1);
-      return;
-    }
   }
 
-  if (SvROK (sv)) {
+  if (!SvOK(sv)) {
+      bson_append_null(bson, key, -1);
+      return;
+  }
+  else if (SvROK (sv)) {
     if (sv_isobject (sv)) {
       /* OIDs */
       if (sv_derived_from (sv, "MongoDB::OID")) {
@@ -588,65 +607,24 @@ sv_to_bson_elem (bson_t * bson, const char * in_key, SV *sv, HV *opts, stackette
       }
       /* 64-bit integers */
       else if (sv_isa(sv, "Math::BigInt")) {
-        int64_t big = 0, offset = 1;
-        int i = 0, length = 0, sign = 1;
-        SV **av_ref, **sign_ref;
-        AV *av;
+        SV *tempsv;
+        char *str;
+        char *end;
+        int64_t big;
 
-        /* get sign */
-        sign_ref = hv_fetchs((HV*)SvRV(sv), "sign", 0);
-        if (!sign_ref) {
-          croak( "couldn't get BigInt sign" );
+        tempsv = sv_2mortal(call_perl_reader(sv, "bstr"));
+        str = SvPV_nolen(tempsv);
+        big = Strtoll(str, &end, 10);
+
+        /* check for conversion problems */
+        if ( errno == ERANGE && ( big == LLONG_MAX || big == LLONG_MIN ) ) {
+          croak( "Math::BigInt '%s' can't fit into a 64-bit integer", str );
         }
-        else if ( SvPOK(*sign_ref) && strcmp(SvPV_nolen( *sign_ref ), "-") == 0 ) {
-          sign = -1;
+        else if ( errno != 0 && big == 0 ) {
+          croak( "couldn't convert Math::BigInt '%s' to 64-bit integer", str );
         }
 
-        /* get value */
-        av_ref = hv_fetchs((HV*)SvRV(sv), "value", 0);
-        if (!av_ref) {
-          croak( "couldn't get BigInt value" );
-        }
-
-        av = (AV*)SvRV(*av_ref);
-
-        if ( av_len( av ) > 3 ) {
-          croak( "BigInt is too large" );
-        }
-
-        for (i = 0; i <= av_len( av ); i++) {
-          int j = 0;
-          SV **val;
-
-          if ( !(val = av_fetch (av, i, 0)) || !(SvPOK(*val) || SvIOK(*val)) ) {
-            sv_dump( sv );
-            croak ("failed to fetch BigInt element");
-          }
-
-          if ( SvIOK(*val) ) {
-            int64_t temp = SvIV(*val);
-
-            while (temp > 0) {
-              temp = temp / 10;
-              length++;
-            }
-
-            temp = (int64_t)(((int64_t)SvIV(*val)) * (int64_t)offset);
-            big = big + temp;
-          }
-          else {
-            STRLEN len = sv_len(*val);
-
-            length += len;
-            big += ((int64_t)atoi(SvPV_nolen(*val))) * offset;
-          }
-
-          for (j = 0; j < length; j++) {
-            offset *= 10;
-          }
-        }
-
-        bson_append_int64(bson, key, -1, big*sign);
+        bson_append_int64(bson, key, -1, big);
       }
       /* Tie::IxHash */
       else if (sv_isa(sv, "Tie::IxHash")) {
@@ -656,6 +634,12 @@ sv_to_bson_elem (bson_t * bson, const char * in_key, SV *sv, HV *opts, stackette
         ixhash_to_bson(&child, sv, opts, stack);
         bson_append_document_end(bson, &child);
       }
+      /* Time::Moment */
+      else if (sv_isa(sv, "Time::Moment")) {
+        SV *sec = sv_2mortal(call_perl_reader(sv, "epoch"));
+        SV *ms = sv_2mortal(call_perl_reader(sv, "millisecond"));
+        bson_append_date_time(bson, key, -1, (int64_t)SvIV(sec)*1000+SvIV(ms));
+      }
       /* DateTime */
       else if (sv_isa(sv, "DateTime")) {
         SV *sec, *ms, *tz, *tz_name;
@@ -908,7 +892,13 @@ sv_to_bson_elem (bson_t * bson, const char * in_key, SV *sv, HV *opts, stackette
       /* if it's publicly an int OR (privately an int AND not publicly a string) */
       if (aggressively_number || (!is_string && (SvIOK(sv) || (SvIOKp(sv) && !SvPOK(sv))))) {
 #if defined(MONGO_USE_64_BIT_INT)
-        bson_append_int64(bson, key, -1, (int64_t)SvIV(sv));
+        IV i = SvIV(sv);
+        if ( i >= INT32_MIN && i <= INT32_MAX) {
+          bson_append_int32(bson, key, -1, (int)i);
+        }
+        else {
+          bson_append_int64(bson, key, -1, (int64_t)i);
+        }
 #else
         bson_append_int32(bson, key, -1, (int)SvIV(sv));
 #endif
@@ -1076,7 +1066,11 @@ get_regex_flags(char * flags, SV *sv) {
          flags_tmp[i] == 'x' ||
          flags_tmp[i] == 's' ) {
       flags[f++] = flags_tmp[i];
-    } else {
+    }
+    else if ( flags_tmp[i] == 'u' ) {
+      /* do nothing as this is default */
+    }
+    else {
       warn( "stripped unsupported regex flag /%c from MongoDB regex\n", flags_tmp[i] );
     }
   }
@@ -1296,47 +1290,50 @@ bson_elem_to_sv (const bson_iter_t * iter, HV *opts ) {
     value = newSViv(bson_iter_int64(iter));
 #else
     char buf[22];
-    SV *as_str = sv_2mortal(newSVpv(buf,0));
-    SV *big_int = sv_2mortal(newSVpvs("Math::BigInt"));
+    SV *as_str;
+    SV *big_int;
     sprintf(buf,"%" PRIi64,bson_iter_int64(iter));
-    load_module(0,big_int,NULL,NULL);
+    as_str = sv_2mortal(newSVpv(buf,0));
+    big_int = sv_2mortal(newSVpvs("Math::BigInt"));
     value = call_method_va(big_int, "new", 1, as_str);
 #endif
     break;
   }
   case BSON_TYPE_DATE_TIME: {
-    double ms_i = bson_iter_date_time(iter);
-
+    const int64_t msec = bson_iter_date_time(iter);
     SV *tempsv;
     const char *dt_type = NULL;
 
-    ms_i /= 1000.0;
-
     if ( (tempsv = _hv_fetchs_sv(opts, "dt_type")) && SvOK(tempsv) ) {
       dt_type = SvPV_nolen(tempsv);
     }
 
     if ( dt_type == NULL ) { 
       /* raw epoch */
-      value = newSViv(ms_i);
+      value = newSViv(msec / 1000);
+    } else if ( strcmp( dt_type, "Time::Moment" ) == 0 ) {
+      SV *tm = sv_2mortal(newSVpvs("Time::Moment"));
+      SV *sec = sv_2mortal(newSViv(msec / 1000));
+      SV *nos = sv_2mortal(newSViv((msec % 1000) * 1000000));
+      value = call_method_va(tm, "from_epoch", 2, sec, nos);
     } else if ( strcmp( dt_type, "DateTime::Tiny" ) == 0 ) {
       time_t epoch;
       struct tm *dt;
-      epoch = bson_iter_time_t(iter);
+      epoch = msec / 1000;
       dt = gmtime( &epoch );
 
       value = new_object_from_pairs(
         dt_type,
-        "year",   newSViv( dt->tm_year + 1900 ),
-        "month",  newSViv( dt->tm_mon  +    1 ),
-        "day",    newSViv( dt->tm_mday ),
-        "hour",   newSViv( dt->tm_hour ),
-        "minute", newSViv( dt->tm_min ),
-        "second", newSViv( dt->tm_sec ),
+        "year",   sv_2mortal(newSViv( dt->tm_year + 1900 )),
+        "month",  sv_2mortal(newSViv( dt->tm_mon  +    1 )),
+        "day",    sv_2mortal(newSViv( dt->tm_mday )),
+        "hour",   sv_2mortal(newSViv( dt->tm_hour )),
+        "minute", sv_2mortal(newSViv( dt->tm_min )),
+        "second", sv_2mortal(newSViv( dt->tm_sec )),
         NULL
       );
     } else if ( strcmp( dt_type, "DateTime" ) == 0 ) {
-      SV *epoch = sv_2mortal(newSVnv(ms_i));
+      SV *epoch = sv_2mortal(newSVnv((NV)msec / 1000));
       value = call_method_with_pairs(
         sv_2mortal(newSVpv(dt_type,0)), "from_epoch", "epoch", epoch, NULL
       );
